==> latte-dock-0.7.95.tar.xz: latte-dock-0.7.95/README.md <==
About
=====
Latte is a dock based on plasma frameworks that provides an elegant and intuitive experience for your tasks and plasmoids. It animates its contents by using parabolic zoom effect and trys to be there only when it is needed.

*"Art in Coffee"*

Screenshots
===========

![](https://cdn.kde.org/screenshots/latte-dock/latte-dock_regular.png)

![](https://cdn.kde.org/screenshots/latte-dock/latte-dock_settings.png)

Installation
============

## Requirements

We recommend that you use at least **Plasma 5.9.0**

**development packages for:**
```bash
 Qt5Core >= 5.9.0
 Qt5Gui >= 5.9.0
 Qt5Dbus >= 5.9.0

 KF5Plasma >= 5.38.0
 KF5PlasmaQuick >= 5.38.0
 KF5Activities >= 5.38.0
 KF5CoreAddons >= 5.38.0
 KF5DBusAddons >= 5.38.0
 KF5Declarative >= 5.38.0
 KF5Wayland >= 5.38.0
 KF5Package >= 5.38.0
 KF5XmlGui >= 5.38.0
 KF5IconThemes >= 5.38.0
 KF5I18n >= 5.38.0
 KF5Notifications >= 5.38.0
 KF5NewStuff >= 5.38.0
 KF5Archive >= 5.38.0
 KF5GlobalAccel >= 5.38.0
 KF5Crash >= 5.38.0

 For X11 support:
    KF5WindowSystem >= 5.38.0
    Qt5X11Extras >= 5.7.0
    libxcb
    libSM
```

## From repositories

### Ubuntu/Debian

- [Ubuntu](https://packages.ubuntu.com/bionic/latte-dock)
- [Rik Mills - ppa](https://launchpad.net/~rikmills/+archive/ubuntu/latte-dock)

### openSUSE

- [openSUSE](https://software.opensuse.org/package/latte-dock?search_term=latte+dock)
- [psifidotos - OBS](https://software.opensuse.org//download.html?project=home%3Apsifidotos&package=latte-dock)

### Fedora

- [Fedora](https://koji.fedoraproject.org/koji/packageinfo?packageID=24229)

### Arch Linux

- [Arch Linux](https://www.archlinux.org/packages/?sort=&q=latte-dock)

### Gentoo

- [Gentoo](https://packages.gentoo.org/packages/kde-misc/latte-dock)

### Solus Project

- [Solus](https://packages.solus-project.com/shannon/l/latte-dock/)

### Void Linux

- [Void Linux](https://github.com/voidlinux/void-packages/tree/master/srcpkgs/latte-dock)

### FreeBSD
- [FreeBSD Port](https://www.freshports.org/deskutils/latte-dock/)

See the [installation instruction](INSTALLATION.md) for others Linux distribution or development build

## Run Latte-Dock

Latte is now ready to be used by executing  ```latte-dock``` or _Latte Dock_ in applications menu.


Contributors
============
[Varlesh](https://github.com/varlesh): Logos and Icons.

==> latte-dock-0.7.96.tar.xz: latte-dock-0.7.96/README.md <==
About
=====
Latte is a dock based on plasma frameworks that provides an elegant and intuitive experience for your tasks and plasmoids. It animates its contents by using parabolic zoom effect and trys to be there only when it is needed.

**"Art in Coffee"**

Screenshots
===========

![](https://cdn.kde.org/screenshots/latte-dock/latte-dock_regular.png)

![](https://cdn.kde.org/screenshots/latte-dock/latte-dock_settings.png)

Installation
============

## Requirements

We recommend that you use at least **Plasma 5.9.0**

**development packages for:**
```bash
 Qt5Core >= 5.9.0
 Qt5Gui >= 5.9.0
 Qt5Dbus >= 5.9.0

 KF5Plasma >= 5.38.0
 KF5PlasmaQuick >= 5.38.0
 KF5Activities >= 5.38.0
 KF5CoreAddons >= 5.38.0
 KF5DBusAddons >= 5.38.0
 KF5Declarative >= 5.38.0
 KF5Wayland >= 5.38.0
 KF5Package >= 5.38.0
 KF5XmlGui >= 5.38.0
 KF5IconThemes >= 5.38.0
 KF5I18n >= 5.38.0
 KF5Notifications >= 5.38.0
 KF5NewStuff >= 5.38.0
 KF5Archive >= 5.38.0
 KF5GlobalAccel >= 5.38.0
 KF5Crash >= 5.38.0

 For X11 support:
    KF5WindowSystem >= 5.38.0
    Qt5X11Extras >= 5.7.0
    libxcb
    libSM
```

## From repositories

### Ubuntu/Debian

- [Ubuntu](https://packages.ubuntu.com/bionic/latte-dock)
- [Rik Mills - ppa](https://launchpad.net/~rikmills/+archive/ubuntu/latte-dock)

### openSUSE

- [openSUSE](https://software.opensuse.org/package/latte-dock?search_term=latte+dock)
- [psifidotos - OBS](https://software.opensuse.org//download.html?project=home%3Apsifidotos&package=latte-dock)

### Fedora

- [Fedora](https://koji.fedoraproject.org/koji/packageinfo?packageID=24229)

### Arch Linux

- [Arch Linux](https://www.archlinux.org/packages/?sort=&q=latte-dock)

### Gentoo

- [Gentoo](https://packages.gentoo.org/packages/kde-misc/latte-dock)

### Solus Project

- [Solus](https://packages.solus-project.com/shannon/l/latte-dock/)

### Void Linux

- [Void Linux](https://github.com/voidlinux/void-packages/tree/master/srcpkgs/latte-dock)

### FreeBSD
- [FreeBSD Port](https://www.freshports.org/deskutils/latte-dock/)

See the [installation instruction](./INSTALLATION.md) for others Linux distribution or development build

## Run Latte-Dock

Latte is now ready to be used by executing 
```latte-dock
```

or activating **Latte Dock** from applications menu.


Contributors
============
[Varlesh](https://github.com/varlesh): Logos and Icons.
